@@ -8,7 +8,8 @@ from BERT_STEM.TrainBERT4PT import *
 
 class BertSTEM:
     
-    def __init__(self, model_name = None)
+    def __init__(self, model_name = None):
+        
         if model_name is not None:
             self.model_name = model_name
 
